List:Commits« Previous MessageNext Message »
From:Daniel Fischer Date:December 7 2006 3:02pm
Subject:bk commit into 4.1 tree (df:1.2564) BUG#24780
View as plain text  
Below is the list of changes that have just been committed into a local
4.1 repository of df. When df does a push these changes will
be propagated to the main repository and, within 24 hours after the
push, to the public repository.
For information on how to access the public repository
see http://dev.mysql.com/doc/mysql/en/installing-source-tree.html

ChangeSet@stripped, 2006-12-07 15:02:32+01:00, df@stripped +3 -0
  BUG#24780 use --sysconfdir in scripts

  scripts/Makefile.am@stripped, 2006-12-07 15:02:31+01:00, df@stripped +1 -0
    pass --sysconfdir to scripts

  scripts/mysqlaccess.sh@stripped, 2006-12-07 15:02:31+01:00, df@stripped +3 -3
    use --sysconfdir instead of hardcoded /etc

  scripts/mysqld_multi.sh@stripped, 2006-12-07 15:02:31+01:00, df@stripped +3 -3
    use --sysconfdir instead of hardcoded /etc

# This is a BitKeeper patch.  What follows are the unified diffs for the
# set of deltas contained in the patch.  The rest of the patch, the part
# that BitKeeper cares about, is below these diffs.
# User:	df
# Host:	kahlann.erinye.com
# Root:	/home/df/mysql/build/mysql-4.1-build-work

--- 1.47/scripts/Makefile.am	2005-09-24 15:51:29 +02:00
+++ 1.48/scripts/Makefile.am	2006-12-07 15:02:31 +01:00
@@ -111,6 +111,7 @@ SUFFIXES = .sh
 	  -e 's!@''pkglibdir''@!$(pkglibdir)!g' \
 	  -e 's!@''pkgincludedir''@!$(pkgincludedir)!g' \
 	  -e 's!@''pkgdatadir''@!$(pkgdatadir)!g' \
+	  -e 's!@''sysconfdir''@!$(sysconfdir)!g' \
 	  -e 's!@''CC''@!@CC@!'\
 	  -e 's!@''CXX''@!@CXX@!'\
 	  -e 's!@''GXX''@!@GXX@!'\

--- 1.10/scripts/mysqlaccess.sh	2005-01-13 11:11:52 +01:00
+++ 1.11/scripts/mysqlaccess.sh	2006-12-07 15:02:31 +01:00
@@ -462,8 +462,8 @@ MySQLaccess::Report::Print_Header();
   if (-f "./$script_conf") {
      require "./$script_conf";
   }
-  elsif (-f "/etc/$script_conf") {
-     require "/etc/$script_conf";
+  elsif (-f "@sysconfdir@/$script_conf") {
+     require "@sysconfdir@/$script_conf";
   }
 
 # ****************************
@@ -929,7 +929,7 @@ sub MergeConfigFile {
 # =================================
 sub MergeConfigFiles {
     my ($name,$pass,$uid,$gid,$quota,$comment,$gcos,$dir,$shell) = getpwuid $<;
-    MergeConfigFile("/etc/my.cnf");
+    MergeConfigFile("@sysconfdir@/my.cnf");
     MergeConfigFile("$dir/.my.cnf");
 }
 

--- 1.23/scripts/mysqld_multi.sh	2006-01-13 17:44:58 +01:00
+++ 1.24/scripts/mysqld_multi.sh	2006-12-07 15:02:31 +01:00
@@ -429,9 +429,9 @@ sub find_groups
   }
   else
   {
-    if (-f "/etc/my.cnf" && -r "/etc/my.cnf")
+    if (-f "@sysconfdir@/my.cnf" && -r "@sysconfdir@/my.cnf")
     {
-      open(MY_CNF, "</etc/my.cnf") && (@tmp=<MY_CNF>) &&
close(MY_CNF);
+      open(MY_CNF, "<@sysconfdir@/my.cnf") && (@tmp=<MY_CNF>) &&
close(MY_CNF);
     }
     for ($i = 0; ($line = shift @tmp); $i++)
     {
@@ -658,7 +658,7 @@ sub example
 #   (as per Linux/Unix standard). You may even replace the
 #   /etc/init.d/mysql.server script with it.
 #
 #   Before using, you must create a my.cnf file either in /etc/my.cnf
 #   or /root/.my.cnf and add the [mysqld_multi] and [mysqld#] groups.
 #
 #   The script can be found from support-files/mysqld_multi.server.sh
@@ -658,7 +658,7 @@ sub example
 #   /etc/init.d/mysql.server script with it.
 #
-#   Before using, you must create a my.cnf file either in /etc/my.cnf
+#   Before using, you must create a my.cnf file either in @sysconfdir@/my.cnf
 #   or /root/.my.cnf and add the [mysqld_multi] and [mysqld#] groups.
 #
Thread
bk commit into 4.1 tree (df:1.2564) BUG#24780Daniel Fischer7 Dec